From: Melanie Plageman <melanieplageman@gmail.com>
To: pgsql-committers@lists.postgresql.org
Subject: pgsql: Use DELETE instead of UPDATE to speed up vacuum test
Date: Mon, 29 Jul 2024 19:46:53 +0000
Message-ID: <E1sYWKb-001mzV-Dt@gemulon.postgresql.org> (raw)
Use DELETE instead of UPDATE to speed up vacuum test
e2e992820f104def introduced a test which generated dead tuples for
vacuum with an UPDATE. The test only required enough dead TIDs for two
rounds of index vacuuming. This can be accomplished with a DELETE
instead of an UPDATE -- which generates about 50% less WAL and makes the
test 20% faster in many cases. The test takes several seconds (more on
slow buildfarm animals) because we need quite a few tuples to trigger
two rounds of index vacuuming; so it is worth a follow-on commit to
speed it up.
Suggested-by: Masahiko Sawada
Discussion: https://postgr.es/m/CAAKRu_bWmMjmqL%2BOZ2duEQ80u7cRvpsExLNZNjzk-pXX5skwMQ%40mail.gmail.com
Backpatch-through: 14, the first version containing this test.
Branch
------
REL_15_STABLE
Details
-------
https://git.postgresql.org/pg/commitdiff/9744fe24118ba5738dda9008533ed00227f5d069
Modified Files
--------------
src/test/recovery/t/043_vacuum_horizon_floor.pl | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-committers@postgresql.org
Cc: melanieplageman@gmail.com, pgsql-committers@lists.postgresql.org
Subject: Re: pgsql: Use DELETE instead of UPDATE to speed up vacuum test
In-Reply-To: <E1sYWKb-001mzV-Dt@gemulon.postgresql.org>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox